#
#  -- switch Finalize
#
#  -- a hack to get the switches to save their information in the case where
#  no pacman installation exists on the first command
#
from Base import *
import os
import Untarzip

def switchFinalize():
	verbo.save()
	debug.save()
	browser.save()
	allow.save()
	upOptions.save()
#	domainMode.save()
	displayMode.save()
	ask.save()
	allow.save()
	
	pre,plat = switchpar('pretend-platform')
	if not pre and len(switchItems('pretend-platform'))>0:
		pre,plat = 1,switchItems('pretend-platform')[0]
	if pre:
		ppl = os.path.join(pac_anchor,pacmanDir,'ppl')
		try:
			removeFile(ppl)
			f = open(ppl,'w')
			f.write(string.strip(plat)+'\n')
			f.close()
		except:
			print "WARNING: Can't write to ["+ppl+"]..."
	
	Untarzip._tarSave.save()
	
	if switch('debug'): removeFile(os.path.join(pac_anchor,pacmanDir,'lock'))
